@@ -1,5 +1,6 @@
 """netports"""
 
+from netports.exceptions import NetportsValueError
 from netports.intf import Intf
 from netports.intf_gm import IntfGM, intfrange
 from netports.ip import IP_NAMES, IP_NUMBERS, iip, sip, ip_pairs
@@ -8,13 +9,14 @@ from netports.ports import inumbers, parse_range, snumbers
 from netports.range import Range
 from netports.tcp import stcp, itcp
 from netports.vlan import ivlan, svlan
-
+from netports.intf_map import short_to_long, short_to_short, long_to_short, long_to_long
 __all__ = [
     "IP_NAMES",
     "IP_NUMBERS",
     "Intf",
     "IntfGM",
     "Item",
+    "NetportsValueError",
     "Range",
     "iip",
     "intfrange",
@@ -22,7 +24,11 @@ __all__ = [
     "ip_pairs",
     "itcp",
     "ivlan",
+    "long_to_long",
+    "long_to_short",
     "parse_range",
+    "short_to_long",
+    "short_to_short",
     "sip",
     "snumbers",
     "stcp",
