@@ -2,11 +2,12 @@
 Sorts the interfaces by indexes (not by alphabetic).
 """
 import re
-from functools import cached_property, total_ordering
+from functools import total_ordering
 from typing import List, Optional, Set, Tuple, Union
 
-from netports.intf_name_map import long_to_short_lower, short_to_long, short_to_long_lower
-from netports.types_ import T3Str, T5Str, LStr, SStr
+from netports import intf_map, helpers as h
+from netports.static import PLATFORMS
+from netports.types_ import T3Str, T5Str, LStr, SStr, DStr
 
 SPLITTER = ",./:"
 
@@ -22,10 +23,12 @@ class Intf:
         ::
             :param line: Interface name that can contain up to 4 indexes
             :type line: str
-
-            :param splitter: Separator characters between indexes, by default ",./:"
+            :param platform: Platform like in Netmiko (default "")
+            :type platform: str
+            :param splitter: Separator of characters between indexes (default ",./:")
             :type splitter: str
         """
+        self._platform = self._init_platform(**kwargs)
         self._splitter = str(kwargs.get("splitter") or SPLITTER)
         self._line = self._init_line(line)
 
@@ -81,6 +84,15 @@ class Intf:
         ]
         return "".join(items)
 
+    @staticmethod
+    def _init_platform(**kwargs) -> str:
+        """Init platform"""
+        platform = str(kwargs.get("platform") or "")
+        expected = ["", *PLATFORMS]
+        if platform not in expected:
+            raise ValueError(f"{platform=} {expected=}")
+        return platform
+
     # =========================== property ===========================
 
     @property
@@ -168,32 +180,18 @@ class Intf:
         """
         return re.sub(r"^interface\s+", "", self.line)
 
-    @cached_property
-    def name_short(self) -> str:
-        """Interface short name with IDs
-        ::
-            :example:
-                intf = Intf("interface FastEthernet1/2")
-                intf.name_short() -> "Fa1/2"
-        """
-        name = self.name.lower()
-        for long, short in long_to_short_lower.items():
-            if name.startswith(long):
-                return name.replace(long, short)
-        return name
+    @property
+    def platform(self) -> str:
+        """Platform"""
+        return self._platform
+
+    @property
+    def splitter(self) -> str:
+        """Separator of characters between indexes"""
+        return self._splitter
 
     # =========================== methods ============================
 
-    def last_idx(self) -> int:
-        """Index of last ID in interface line
-        ::
-            :example:
-                intf = Intf("interface Ethernet1/2/3.4")
-                intf.last_idx() -> 4
-        """
-        ids = self._ids[1:]
-        return len([s for s in ids if s])
-
     def all_names(self) -> LStr:
         """All variants of names: long, short, upper-case, lover-case
         ::
@@ -210,20 +208,25 @@ class Intf:
                 ]
         """
         results: SStr = set()
-        for name_ in [self.line, self.name]:
+        names_: LStr = [self.line, self.name, self.name_full(), self.name_long(), self.name_short()]
+        names_ = h.no_dupl(names_)
+        for name_ in names_:
             results.add(name_)
             if not name_.startswith("interface "):
                 name_ = f"interface {name_}"
                 results.add(name_)
-        # results.add(self.name_short)
 
-        for name in [self.name, self.name_short]:
-            intf_o = Intf(name)
-            for id0_short, map_d in [
-                (intf_o.id0, short_to_long),
-                (intf_o.id0.lower(), short_to_long_lower),
+        intf_map_upper: DStr = intf_map.short_to_long(self._platform)
+        intf_map_lower: DStr = intf_map.short_to_long(self._platform, key_lower=True)
+        names: LStr = [self.name, self.name_short()]
+        names = h.no_dupl(names)
+        for name in names:
+            intf_o = Intf(line=name, platform=self.platform)
+            for id0_short, intf_map_d in [
+                (intf_o.id0, intf_map_upper),
+                (intf_o.id0.lower(), intf_map_lower),
             ]:
-                if id0_long := map_d.get(id0_short) or "":
+                if id0_long := intf_map_d.get(id0_short) or "":
                     name_long = intf_o.line.replace(id0_short, id0_long, 1)
                     results.add(name_long)
                     if not name_long.startswith("interface "):
@@ -232,31 +235,164 @@ class Intf:
         results.update([s.lower() for s in results])
         results_: LStr = sorted(results)
         results_.sort(key=len, reverse=True)
+
+        if self.platform == "hp_procurve":
+            if digits := [s for s in results if s.isdigit()]:
+                names = [f"interface 1/{s}" for s in digits]
+                results_.extend(names)
         return results_
 
-    def part(self, idx: int) -> str:
-        """Interface part before interested ID
+    def last_idx(self) -> int:
+        """Index of last ID in interface line
         ::
             :example:
                 intf = Intf("interface Ethernet1/2/3.4")
-                intf.parts(2) -> "Ethernet1/"
+                intf.last_idx() -> 4
+        """
+        ids = self._ids[1:]
+        return len([s for s in ids if s])
+
+    def name_full(self) -> str:
+        """Interface long name with IDs and with interface keyword
+        ::
+            :example:
+                intf = Intf("Eth1/2")
+                intf.name_full() -> "interface Ethernet1/2"
+        """
+        name = self.name_long()
+        return f"interface {name}"
+
+    # noinspection DuplicatedCode
+    def name_long(self) -> str:
+        """Interface long name with IDs and without interface keyword
+        ::
+            :example:
+                intf = Intf("Eth1/2")
+                intf.name_long() -> "Ethernet1/2"
+        """
+        id0 = self.id0.lower()
+        if id0.startswith("interface "):
+            id0 = id0.replace("interface ", "", 1)
+
+        intf_map_short: DStr = intf_map.short_to_long(self._platform, key_lower=True)
+        for short_lower, long_upper in intf_map_short.items():
+            if id0 == short_lower:
+                id0 = long_upper
+                break
+        else:
+            intf_map_long: DStr = intf_map.long_to_long(self._platform, key_lower=True)
+            for long_lower, long_upper in intf_map_long.items():
+                if id0 == long_lower:
+                    id0 = long_upper
+                    break
+
+        id1 = self.part_after(idx=0)
+        name = f"{id0}{id1}"
+        return name
+
+    # noinspection DuplicatedCode
+    def name_short(self) -> str:
+        """Interface short name with IDs
+        ::
+            :example:
+                intf = Intf("interface FastEthernet1/2")
+                intf.name_short() -> "Fa1/2"
+        """
+        id0 = self.id0.lower()
+        if id0.startswith("interface "):
+            id0 = id0.replace("interface ", "", 1)
+
+        intf_map_l2s: DStr = intf_map.long_to_short(self._platform, key_lower=True)
+        for long_lower, short_upper in intf_map_l2s.items():
+            if id0 == long_lower:
+                id0 = short_upper
+                break
+        else:
+            intf_map_s2s: DStr = intf_map.short_to_short(self._platform, key_lower=True)
+            for short_lower, short_upper in intf_map_s2s.items():
+                if id0 == short_lower:
+                    id0 = short_upper
+                    break
+
+        id1 = self.part_after(idx=0)
+        name = f"{id0}{id1}"
+        return name
+
+    def part_after(self, idx: int, splitter=True) -> str:
+        """Interface part after interested ID
+        ::
+            :param idx: Interface index
+            :param splitter: True - Include splitter from edge, False - Skip splitter from edge
+            :return: Part of the interface name after specified interface index
+            :example:
+                intf = Intf("Ethernet1/2/3.4")
+                intf.part_after(2) -> "/3.4"
+                intf.part_after(3) -> ".4"
+                intf.part_after(2, splitter=False) -> "3.4"
+        """
+        if idx >= 4:
+            return ""
+
+        parts = self._ids[4]
+        if idx == 3:
+            if splitter:
+                return self._dels[2] + parts
+            return parts
+
+        parts = self._ids[3] + self._dels[2] + parts
+        if idx == 2:
+            if splitter:
+                return self._dels[1] + parts
+            return parts
+
+        parts = self._ids[2] + self._dels[1] + parts
+        if idx == 1:
+            if splitter:
+                return self._dels[0] + parts
+            return parts
+
+        parts = self._ids[1] + self._dels[0] + parts
+        if idx == 0:
+            return parts
+
+        parts = self._ids[0] + parts
+        return parts
+
+    def part_before(self, idx: int, splitter=True) -> str:
+        """Interface part before interested ID
+        ::
+            :param idx: Interface index
+            :param splitter: True - Include splitter from edge, False - Skip splitter from edge
+            :return: Part of the interface name before specified interface index
+            :example:
+                intf = Intf("Ethernet1/2/3.4")
+                intf.part_before(2) -> "Ethernet1/"
+                intf.part_before(3) -> "Ethernet1/2/"
+                intf.part_before(3, splitter=False) -> "Ethernet1/2"
         """
         if idx <= 0:
             return ""
+
         parts = self._ids[0]
         if idx == 1:
             return parts
 
-        parts += self._ids[1] + self._dels[0]
+        parts += self._ids[1]
         if idx == 2:
+            if splitter:
+                return parts + self._dels[0]
             return parts
 
-        parts += self._ids[2] + self._dels[1]
+        parts += self._dels[0] + self._ids[2]
         if idx == 3:
+            if splitter:
+                return parts + self._dels[1]
             return parts
 
-        parts += self._ids[3] + self._dels[2]
+        parts += self._dels[1] + self._ids[3]
         if idx == 4:
+            if splitter:
+                return parts + self._dels[2]
             return parts
 
         return self._line
